summaryrefslogtreecommitdiffstats
path: root/cpukit/sapi/include/rtems/fatal.h
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/sapi/include/rtems/fatal.h')
-rw-r--r--cpukit/sapi/include/rtems/fatal.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/cpukit/sapi/include/rtems/fatal.h b/cpukit/sapi/include/rtems/fatal.h
index b4b3b0fe6e..03cfafa8d0 100644
--- a/cpukit/sapi/include/rtems/fatal.h
+++ b/cpukit/sapi/include/rtems/fatal.h
@@ -73,17 +73,20 @@ void rtems_fatal_error_occurred(
) RTEMS_NO_RETURN;
/**
- * @brief Invokes the internal error handler with is internal set to false.
+ * @brief Terminates the system.
*
* @param[in] source is the fatal source.
* @param[in] error is the fatal code.
*
* @see _Terminate().
*/
-void rtems_fatal(
- rtems_fatal_source source,
- rtems_fatal_code error
-) RTEMS_NO_RETURN;
+RTEMS_INLINE_ROUTINE void rtems_fatal(
+ rtems_fatal_source fatal_source,
+ rtems_fatal_code error_code
+)
+{
+ _Terminate( fatal_source, error_code );
+}
/**
* @brief Returns a text for a fatal source.
@@ -73,17 +73,20 @@ void rtems_fatal_error_occurred(
*
- * @param[in] source is the fatal source.
- * @param[in] error is the fatal code.
+ * @param[in] fatal_source The fatal source.
+ * @param[in] error_code The error code.
*
* @see _Terminate().